==> file?get=wackowiki-6.0.38.zip: wackowiki-6.0.38/src/js/lang/wikiedit.it.js <==
lang = {
	// default.js
	ReallySave :			"Really save?",
	ModifiedHint :			"Field has changed, do not forget to save the changes.",
	NotSavedWarning :		"You did not save changes. Are you sure you want to leave?",
	SessionExpiredEditor :	"La tua sessione è scaduta!\nSei stato disconnesso a causa di una lunga inattività.\n1. Salva il tuo modulo modificato in un file di testo per evitare perdite.\n2. Aggiorna la pagina.\n3. Effettuare di nuovo il login e ripresentarsi.",

	// wikiedit.js
	HelpAbout :				"Aiuto & Informazioni",
	HelpFormatting :		"Aiuto",
	HelpFormattingTip :		"Aiuto nella formattazione Wiki",
	HelpFormattingPage :	"Doc/English/Formatting",

	Heading1 :				"Intestazione 1",
	Heading2 :				"Intestazione 2",
	Heading3 :				"Intestazione 3",
	Heading4 :				"Intestazione 4",
	Heading5 :				"Intestazione 5",
	Heading6 :				"Intestazione 6",
	Bold :					"Grassetto",
	Italic :				"Corsivo",
	Underline :				"Sottolineato",
	Strikethrough :			"Barrato",
	Small :					"Piccola",
	Code :					"Codice",
	Superscript :			"Apice",
	Subscript :				"Pedice",
	List :					"Elenco puntato",
	NumberedList :			"Elenco numerato",
	Left :					"Sinistra",
	Center :				"Centro",
	Right :					"Destra",
	Justify :				"Giustificato",
	Outdent :				"Meno indentato",
	Indent :				"Più indentato",
	CodeWrapper :			"Code Wrapper",
	HTML :					"HTML",
	Action :				"Action",
	Line :					"Riga orizzontale",
	Signature :				"Inserisci la firma",
	Quote :					"Quote",
	MarkedText :			"Marked text",
	HighlightText :			"Highlight text",
	Shade :					"Shade",
	Footnote :				"Nota a piè di pagina",
	Hyperlink :				"Hyperlink",
	InsertTable :			"Inserire tabella",

	Link :					"Link",
	TextForLinking :		"Text for linking",

	HelpAboutTip :			' Shortcuts:\n'+
							' Ctrl+B - Bold\n'+
							' Ctrl+I - Italic\n'+
							' Ctrl+U - Underline\n'+
							' Ctrl+Shift+S - Strikethrough\n'+
							' Ctrl+Shift+1 .. 4 - Heading 1..4\n'+
							' Alt+I or Ctrl+T - Indent\n'+
							' Alt+U or Ctrl+Shift+T - Unindent\n'+
							' Ctrl+J - MarkUp (!!)\n'+
							' Ctrl+H - MarkUp (??)\n'+
							' Alt+L - Link\n'+
							' Ctrl+L - Link with description\n'+
							' Ctrl+Shift+L - Unordered List\n'+
							' Ctrl+Shift+N - Ordered List\n'+
							' Ctrl+Shift+O - Ordered List\n'+
							' Ctrl+= - Small text\n'+
							' Ctrl+Shift+Minus - Horizontal line\n'+
							' \n'
};

==> file?get=wackowiki-6.2.0.zip: wackowiki-6.2.0/src/js/lang/wikiedit.it.js <==
lang = {
	// default.js
	ReallySave :			"Salvare davvero?",
	ModifiedHint :			"Il campo è cambiato, non dimenticare di salvare le modifiche.",
	NotSavedWarning :		"Non hai salvato le modifiche. Sei sicuro di voler uscire?",
	SessionExpiredEditor :	"La tua sessione è scaduta!\nSei stato disconnesso a causa di una lunga inattività.\n1. Salva il tuo modulo modificato in un file di testo per evitare perdite.\n2. Aggiorna la pagina.\n3. Effettuare di nuovo il login e ripresentarsi.",

	// wikiedit.js
	HelpAbout :				"Aiuto & Informazioni",
	HelpFormatting :		"Aiuto",
	HelpFormattingTip :		"Aiuto nella formattazione Wiki",
	HelpFormattingPage :	"Doc/English/Formatting",

	Heading1 :				"Intestazione 1",
	Heading2 :				"Intestazione 2",
	Heading3 :				"Intestazione 3",
	Heading4 :				"Intestazione 4",
	Heading5 :				"Intestazione 5",
	Heading6 :				"Intestazione 6",
	Bold :					"Grassetto",
	Italic :				"Corsivo",
	Underline :				"Sottolineato",
	Strikethrough :			"Barrato",
	Small :					"Piccola",
	Code :					"Codice",
	Superscript :			"Apice",
	Subscript :				"Pedice",
	List :					"Elenco puntato",
	NumberedList :			"Elenco numerato",
	Left :					"Sinistra",
	Center :				"Centro",
	Right :					"Destra",
	Justify :				"Giustificato",
	Outdent :				"Meno indentato",
	Indent :				"Più indentato",
	CodeWrapper :			"Code Wrapper",
	HTML :					"HTML",
	Action :				"Azione",
	Line :					"Riga orizzontale",
	Signature :				"Inserisci la firma",
	Quote :					"Preventivo",
	MarkedText :			"Testo contrassegnato",
	HighlightText :			"Evidenzia testo",
	Shade :					"Ombra",
	Footnote :				"Nota a piè di pagina",
	Hyperlink :				"Hyperlink",
	InsertTable :			"Inserire tabella",

	Link :					"Link",
	TextForLinking :		"TTesto per il collegamento",

	HelpAboutTip :			' Scorciatoie:\n'+
							' Ctrl+B - Grassetto\n'+
							' Ctrl+I - Italic\n'+
							' Ctrl+U - Sottolinea\n'+
							' Ctrl+Shift+S - Sbarratura\n'+
							' Ctrl+Shift+1 .. 4 - Intestazione 1..4\n'+
							' Alt+I or Ctrl+T - Rientro\n'+
							' Alt+U or Ctrl+Shift+T - Unindent\n'+
							' Ctrl+J - MarkUp (!!)\n'+
							' Ctrl+H - MarkUp (??)\n'+
							' Alt+L - Link\n'+
							' Ctrl+L - Collega con la descrizione\n'+
							' Ctrl+Shift+L - Elenco Non Ordinato\n'+
							' Ctrl+Shift+N - Elenco Ordinato\n'+
							' Ctrl+Shift+O - Elenco Ordinato\n'+
							' Ctrl+= - Testo piccolo\n'+
							' Ctrl+Shift+Minus - Linea orizzontale\n'+
							' \n'
};
